==> vee_1.9-0.tar.gz: vee-1.9/setup.py <==
# -*- coding: utf-8 -*-
from distutils.core import setup

from distutils.command.install_lib import install_lib
from distutils.command.install_data import install_data

import sys, os, stat, sre, glob

try:
	if sys.version_info < (2, 3):
		print "VEE requires Python 2.3 or higher"
		sys.exit(1)
except AttributeError:
	print "VEE requires Python 2.3 or higher"
	sys.exit(1)

import msgfmt

# get fakeroot directory if exists.
DIR_FAKEROOT = "/"
for i in range(len(sys.argv)) :
	__a = sys.argv[i].split("=")
	if len(__a) > 1 :
		if __a[0] == "--fakeroot" :
			DIR_FAKEROOT = __a[1]
			del(sys.argv[i])

DIR_EXEC = "bin"
DIR_LIB = "lib/vee/"

DIR_INSTALLED_LIB = None

class my_install_lib (install_lib) :
	def finalize_options (self) :
		global DIR_INSTALLED_LIB
		global DIR_INSTALLED_LIB_FAKED

		install_lib.finalize_options(self)

		DIR_INSTALLED_LIB = self.install_dir
		self.install_dir = os.path.join( \
			DIR_FAKEROOT, sre.compile("^\/").sub("", self.install_dir))

		DIR_INSTALLED_LIB_FAKED = self.install_dir

class my_install_data (install_data) :

	def finalize_options (self) :
		global DIR_INSTALLED_LIB
		global DIR_INSTALLED_LIB_FAKED
		global DIR_FAKEROOT

		install_data.finalize_options(self)
		DIR_INSTALL = self.install_dir

		self.install_dir = os.path.join( \
			DIR_FAKEROOT, sre.compile("^\/").sub("", self.install_dir))

		# create exec directory.
		__dir_exec = os.path.join(self.install_dir, DIR_EXEC)
		__dir_lib = os.path.join(self.install_dir, DIR_LIB)

		if not os.path.exists(__dir_exec) :
			os.mkdir(__dir_exec)
		else :
			if not os.path.isdir(__dir_exec) :
				print "%s must be a directory!" % __dir_exec
				sys.exit(1)

		if not os.path.exists(__dir_lib) :
			os.mkdir(__dir_lib)
		else :
			if not os.path.isdir(__dir_lib) :
				print "%s must be a directory!" % __dir_lib
				sys.exit(1)

		# make a symbolic link. vee.py to PREFIX/bin/vee(t)
		__src_vee = os.path.join(DIR_INSTALLED_LIB, "vee", "vee.py")
		__target_vee = os.path.join(self.install_dir, DIR_EXEC, "vee")

		__src_veet = os.path.join(DIR_INSTALLED_LIB, "vee", "veet.py")
		__target_veet = os.path.join(self.install_dir, DIR_EXEC, "veet")

		try :
			if os.path.islink(__target_vee) : os.remove(__target_vee)
			if os.path.islink(__target_veet) : os.remove(__target_veet)

			#os.symlink(__src_vee, __target_vee)
			#os.symlink(__src_veet, __target_veet)
			os.system("ln -s '%s' '%s'" % (__src_vee, __target_vee))
			os.system("ln -s '%s' '%s'" % (__src_veet, __target_veet))
		except :
			print "failed to create a symbolic link."
		else :
			print "Create symbolic link for vee, veet."

		# set the permission, 755 to vee(t).py
		os.chmod( \
			os.path.join(DIR_INSTALLED_LIB_FAKED, "vee", "vee.py"), \
			stat.S_IRWXU | \
			stat.S_IRGRP | stat.S_IXGRP | \
			stat.S_IROTH | stat.S_IXOTH \
		)

		os.chmod( \
			os.path.join(DIR_INSTALLED_LIB_FAKED, "vee", "veet.py"), \
			stat.S_IRWXU | \
			stat.S_IRGRP | stat.S_IXGRP | \
			stat.S_IROTH | stat.S_IXOTH \
		)

		# set the file path in Conf.py
		__f_conf_py = open(os.path.join("src/Conf.py.in"), "r")
		__conf_py = "".join(__f_conf_py.readlines())
		__f_conf_py.close()

		__f_glade = open(os.path.join("src/vee.glade.in"), "r")
		__glade = "".join(__f_glade.readlines())
		__f_glade.close()

		__conf_py0 = __conf_py.replace( \
			"@DIR_LIBFILE@", \
			os.path.join(DIR_INSTALL, DIR_LIB) \
		).replace( \
			"@DIR_PIXMAPS@", \
			os.path.join(DIR_INSTALL, "share/pixmaps/vee/") \
		).replace( \
			"@DIR_LOCALE@", \
			os.path.join(DIR_INSTALL, "share/locale/") \
		)

		f = open(os.path.join(DIR_INSTALLED_LIB_FAKED, "vee", "Conf.py"), "w")
		f.write(__conf_py0)
		f.close()

		__glade0 = __glade.replace( \
			"@DIR_LIBFILE@", \
			os.path.join(DIR_INSTALL, DIR_LIB) \
		).replace( \
			"@DIR_PIXMAPS@", \
			os.path.join(DIR_INSTALL, "share/pixmaps/vee/") \
		)
		f = open(os.path.join(self.install_dir, DIR_LIB, "vee.glade"), "w")
		f.write(__glade0)
		f.close()

		# build po file and install mo files.
		mo = msgfmt.msgfmt()
		__po_files = glob.glob(os.path.join("src", "i18n", "*.po"))
		if len(__po_files) > 0 :
			for i in __po_files :
				mo.make(i)

			__mo_files =  glob.glob(os.path.join("src", "i18n", "*.mo"))
			if len(__mo_files) > 0 :
				__skel = "%s/share/locale/%s/LC_MESSAGES/"
				for i in glob.glob(os.path.join("src", "i18n", "*.mo")) :

					__lang = os.path.basename(i).split(".")[0]
					__target_dir = __skel % (self.install_dir, __lang)
					__target_file = "%s/vee.mo" % __target_dir

					if os.path.exists(__target_file) :
						os.remove(__target_file)

					if not os.path.exists(__target_dir) :
						os.makedirs(__target_dir)

					os.rename(i, __target_file)

setup( \
	name = "vee", \
	description = "VEE, Vim Editor Embedded", \
	author = "Spike^ekipS",
	author_email = "SpikeekipS@gmail.com",
	license = "GPL",
	platforms = "ALL",
	url = "http://kldp.net/projects/vee/",
 	version = "1.2", \
	packages = ["vee", "vee.child"], \
	package_dir = {"vee" : "src"}, \
	data_files = [ \
		(DIR_LIB, ["src/vee.schema", "src/vee.gladep"]),
		("share/pixmaps/vee", glob.glob("src/pixmaps/*.png")),
		("share/doc/vee", \
			["src/doc/AUTHORS", "src/doc/COPYING", "src/doc/ChangeLog",
			"src/doc/INSTALL", "src/doc/PACKAGE"]),
	], \
	cmdclass = { \
		"install_lib" : my_install_lib,
		"install_data" : my_install_data,
	}
)

"""
Description
-----------
VEE install script for python.

ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "setup.py"

==> vee_2.1-0.tar.gz: vee-2.1/setup.py <==
# -*- coding: utf-8 -*-
#    Copyright 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from distutils.core import setup

from distutils.command.install_lib import install_lib
from distutils.command.install_data import install_data

import sys, os, stat, sre, glob, shutil

try:
	if sys.version_info < (2, 3):
		print "VEE requires Python 2.3 or higher"
		sys.exit(1)
except AttributeError:
	print "VEE requires Python 2.3 or higher"
	sys.exit(1)

import msgfmt

# get fakeroot directory if exists.
DIR_FAKEROOT = "/"
for i in range(len(sys.argv)) :
	__a = sys.argv[i].split("=")
	if len(__a) > 1 :
		if __a[0] == "--fakeroot" :
			DIR_FAKEROOT = __a[1]
			del(sys.argv[i])

DIR_EXEC = "bin"
DIR_LIB = "lib/vee/"

DIR_INSTALLED_LIB = None

class my_install_lib (install_lib) :
	def finalize_options (self) :
		global DIR_INSTALLED_LIB
		global DIR_INSTALLED_LIB_FAKED

		install_lib.finalize_options(self)

		DIR_INSTALLED_LIB = self.install_dir
		self.install_dir = os.path.join( \
			DIR_FAKEROOT, sre.compile("^\/").sub("", self.install_dir))

		DIR_INSTALLED_LIB_FAKED = self.install_dir

class my_install_data (install_data) :

	def finalize_options (self) :
		global DIR_INSTALLED_LIB
		global DIR_INSTALLED_LIB_FAKED
		global DIR_FAKEROOT

		install_data.finalize_options(self)
		DIR_INSTALL = self.install_dir

		self.install_dir = os.path.join( \
			DIR_FAKEROOT, sre.compile("^\/").sub("", self.install_dir))

		# create exec directory.
		__dir_exec = os.path.join(self.install_dir, DIR_EXEC)
		__dir_lib = os.path.join(self.install_dir, DIR_LIB)

		if not os.path.exists(__dir_exec) :
			os.mkdir(__dir_exec)
		else :
			if not os.path.isdir(__dir_exec) :
				print "%s must be a directory!" % __dir_exec
				sys.exit(1)

		if not os.path.exists(__dir_lib) :
			os.mkdir(__dir_lib)
		else :
			if not os.path.isdir(__dir_lib) :
				print "%s must be a directory!" % __dir_lib
				sys.exit(1)

		# set the permission, 755 to vee(t).py
		os.chmod( \
			os.path.join(DIR_INSTALLED_LIB_FAKED, "vee", "vee.py"), \
			stat.S_IRWXU | \
			stat.S_IRGRP | stat.S_IXGRP | \
			stat.S_IROTH | stat.S_IXOTH \
		)

		os.chmod( \
			os.path.join(DIR_INSTALLED_LIB_FAKED, "vee", "veet.py"), \
			stat.S_IRWXU | \
			stat.S_IRGRP | stat.S_IXGRP | \
			stat.S_IROTH | stat.S_IXOTH \
		)

		# set the file path in Conf.py
		__f_conf_py = open(os.path.join("src/Conf.py.in"), "r")
		__conf_py = "".join(__f_conf_py.readlines())
		__f_conf_py.close()

		__f_glade = open(os.path.join("src/vee.glade.in"), "r")
		__glade = "".join(__f_glade.readlines())
		__f_glade.close()

		__conf_py0 = __conf_py.replace( \
			"@DIR_LIBFILE@", \
			os.path.join(DIR_INSTALL, DIR_LIB) \
		).replace( \
			"@DIR_PIXMAPS@", \
			os.path.join(DIR_INSTALL, "share/pixmaps/vee/") \
		).replace( \
			"@DIR_LOCALE@", \
			os.path.join(DIR_INSTALL, "share/locale/") \
		).replace( \
			"@DIR_SHARE@", \
			os.path.join(DIR_INSTALL, "share/") \
		)

		f = open(os.path.join(DIR_INSTALLED_LIB_FAKED, "vee", "Conf.py"), "w")
		f.write(__conf_py0)
		f.close()

		__glade0 = __glade.replace( \
			"@DIR_LIBFILE@", \
			os.path.join(DIR_INSTALL, DIR_LIB) \
		).replace( \
			"@DIR_PIXMAPS@", \
			os.path.join(DIR_INSTALL, "share/pixmaps/vee/") \
		).replace( \
			"@DIR_SHARE@", \
			os.path.join(DIR_INSTALL, "share/") \
		)
		f = open(os.path.join(self.install_dir, DIR_LIB, "vee.glade"), "w")
		f.write(__glade0)
		f.close()

		# create executive file and make a symbolic link. veet.py to PREFIX/bin/veet
		__src_vee = os.path.join(DIR_INSTALLED_LIB, "vee", "vee.py")
		__target_vee = os.path.join(self.install_dir, DIR_EXEC, "vee")

		__src_veet = os.path.join(DIR_INSTALLED_LIB, "vee", "veet.py")
		__target_veet = os.path.join(self.install_dir, DIR_EXEC, "veet")

		__f_vee = open(os.path.join("src/vee.in"), "r")
		__vee = "".join(__f_vee.readlines())
		__f_vee.close()

		__vee0 = __vee.replace( \
			"@FILE_VEE.PY@", \
			os.path.join(os.path.join(DIR_INSTALLED_LIB, "vee", "vee.py")) \
		)
		f = open(os.path.join(__target_vee), "w")
		f.write(__vee0)
		f.close()

		os.chmod( \
			os.path.join(__target_vee), \
			stat.S_IRWXU | \
			stat.S_IRGRP | stat.S_IXGRP | \
			stat.S_IROTH | stat.S_IXOTH \
		)

		try :
			if os.path.islink(__target_vee) : os.remove(__target_vee)
			if os.path.islink(__target_veet) : os.remove(__target_veet)

			#os.symlink(__src_vee, __target_vee)
			#os.symlink(__src_veet, __target_veet)
			#os.system("ln -s '%s' '%s'" % (__src_vee, __target_vee))
			os.system("ln -s '%s' '%s'" % (__src_veet, __target_veet))
		except :
			print "failed to create a symbolic link."
		else :
			print "Create symbolic link for vee, veet."

		# install help files.
		__help_dirs = glob.glob(os.path.join("src", "doc", "help", "*"))
		if len(__help_dirs) > 0 :
			__targetdir = "%s/share/gnome/help/vee/%s"
			__targetdir0 = "%s/share/gnome/help/vee/" % self.install_dir
			for i in glob.glob(os.path.join("src", "doc", "help", "*")) :
				if not os.path.exists(__targetdir0) :
					os.makedirs(__targetdir0)

				shutil.copytree(i, __targetdir % (self.install_dir, i.split(os.sep)[-1]))

		# build po file and install mo files.
		mo = msgfmt.msgfmt()
		__po_files = glob.glob(os.path.join("src", "i18n", "*.po"))
		if len(__po_files) > 0 :
			for i in __po_files :
				mo.make(i)

			__mo_files =  glob.glob(os.path.join("src", "i18n", "*.mo"))
			if len(__mo_files) > 0 :
				__skel = "%s/share/locale/%s/LC_MESSAGES/"
				for i in glob.glob(os.path.join("src", "i18n", "*.mo")) :

					__lang = os.path.basename(i).split(".")[0]
					__target_dir = __skel % (self.install_dir, __lang)
					__target_file = "%s/vee.mo" % __target_dir

					if os.path.exists(__target_file) :
						os.remove(__target_file)

					if not os.path.exists(__target_dir) :
						os.makedirs(__target_dir)

					os.rename(i, __target_file)

setup( \
	name = "vee", \
	description = "VEE, Vim Editor Embedded", \
	author = "Spike^ekipS",
	author_email = "SpikeekipS@gmail.com",
	license = "GPL",
	platforms = "ALL",
	url = "http://kldp.net/projects/vee/",
 	version = "1.2", \
	packages = ["vee", "vee.child"], \
	package_dir = {"vee" : "src"}, \
	data_files = [ \
		(DIR_LIB, ["src/vee.schema", "src/vee.gladep", "src/matrix.vim"]),
		("share/pixmaps/vee", glob.glob("src/pixmaps/*.png")),
		("share/applications", ["src/vee.desktop",]),
		("share/doc/vee", \
			["src/doc/AUTHORS", "src/doc/COPYING", "src/doc/ChangeLog",
			"src/doc/INSTALL.ko", "src/doc/INSTALL.en", "src/doc/PACKAGE"]),
	], \
	cmdclass = { \
		"install_lib" : my_install_lib,
		"install_data" : my_install_data,
	}
)

"""
Description
-----------
VEE install script for python.

ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "setup.py"
